- The folder components contains the studied components. 
- They were generated using the code from `references.ipynb` notebook (for link, see root of this repo). 
- The top-most node is the root node (box-shaped). 
- The summary table shows the resulting statistics.